Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(868)

Unified Diff: chrome/browser/ui/cocoa/browser_window_controller.h

Issue 2459653005: [Mac] Refactor the Fullscreen Toolbar Visibility Locks (Closed)
Patch Set: Fix for rsesek Created 4 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/cocoa/browser_window_controller.h
diff --git a/chrome/browser/ui/cocoa/browser_window_controller.h b/chrome/browser/ui/cocoa/browser_window_controller.h
index 75f475ba00d1c1a4e574ad0959e0552ec5cdc9c2..0d75b5b9c8f3d9336016609ecc8f0a3690078c0a 100644
--- a/chrome/browser/ui/cocoa/browser_window_controller.h
+++ b/chrome/browser/ui/cocoa/browser_window_controller.h
@@ -43,13 +43,14 @@ class ExclusiveAccessController;
class ExclusiveAccessContext;
@class FindBarCocoaController;
@class FullscreenModeController;
+@class FullscreenToolbarController;
+@class FullscreenToolbarVisibilityLockController;
@class FullscreenWindow;
class FullscreenLowPowerCoordinatorCocoa;
@class InfoBarContainerController;
class LocationBarViewMac;
@class OverlayableContentsController;
class PermissionBubbleCocoa;
-@class FullscreenToolbarController;
class StatusBubbleMac;
@class TabStripController;
@class TabStripView;
@@ -181,17 +182,6 @@ class Command;
// The proportion of the floating bar which is shown.
CGFloat floatingBarShownFraction_;
- // Various UI elements/events may want to ensure that the floating bar is
- // visible (in presentation mode), e.g., because of where the mouse is or
- // where keyboard focus is. Whenever an object requires bar visibility, it has
- // itself added to |barVisibilityLocks_|. When it no longer requires bar
- // visibility, it has itself removed.
- base::scoped_nsobject<NSMutableSet> barVisibilityLocks_;
-
- // Bar visibility locks and releases only result (when appropriate) in changes
- // in visible state when the following is |YES|.
- BOOL barVisibilityUpdatesEnabled_;
-
// If this ivar is set to YES, layoutSubviews calls will be ignored. This is
// used in fullscreen transition to prevent spurious resize messages from
// being sent to the renderer, which causes the transition to be janky.
@@ -567,11 +557,11 @@ class Command;
// owner are ignored. If |animate:| is YES, then an animation may be
// performed. In the case of multiple calls, later calls have precedence with
// the rule that |animate:NO| has precedence over |animate:YES|. If |owner| is
// nil in isBarVisibilityLockedForOwner, the method returns YES if there are
// any locks.
-- (BOOL)isBarVisibilityLockedForOwner:(id)owner;
-- (void)lockBarVisibilityForOwner:(id)owner withAnimation:(BOOL)animate;
-- (void)releaseBarVisibilityForOwner:(id)owner withAnimation:(BOOL)animate;
+- (BOOL)isToolbarVisibilityLockedForOwner:(id)owner;
+- (void)lockToolbarVisibilityForOwner:(id)owner withAnimation:(BOOL)animate;
+- (void)releaseToolbarVisibilityForOwner:(id)owner withAnimation:(BOOL)animate;
// Returns YES if any of the views in the floating bar currently has focus.
- (BOOL)floatingBarHasFocus;

Powered by Google App Engine
This is Rietveld 408576698
@@ -567,11 +557,11 @@ class Command;
// performed. In the case of multiple calls, later calls have precedence with
// the rule that |animate:NO| has precedence over |animate:YES|. If |owner| is
-// nil in isBarVisibilityLockedForOwner, the method returns YES if there are
+// nil in isToolbarVisibilityLockedForOwner, the method returns YES if there are
// any locks.